#[repr(u32)]pub enum b2BodyType {
b2_staticBody = 0,
b2_kinematicBody = 1,
b2_dynamicBody = 2,
}Expand description
The body type. static: zero mass, zero velocity, may be manually moved kinematic: zero mass, non-zero velocity set by user, moved by solver dynamic: positive mass, non-zero velocity determined by forces, moved by solver
Variants