#[repr(u32)]pub enum b2ParticleFlag {
Show 18 variants
b2_waterParticle = 0,
b2_zombieParticle = 2,
b2_wallParticle = 4,
b2_springParticle = 8,
b2_elasticParticle = 16,
b2_viscousParticle = 32,
b2_powderParticle = 64,
b2_tensileParticle = 128,
b2_colorMixingParticle = 256,
b2_destructionListenerParticle = 512,
b2_barrierParticle = 1_024,
b2_staticPressureParticle = 2_048,
b2_reactiveParticle = 4_096,
b2_repulsiveParticle = 8_192,
b2_fixtureContactListenerParticle = 16_384,
b2_particleContactListenerParticle = 32_768,
b2_fixtureContactFilterParticle = 65_536,
b2_particleContactFilterParticle = 131_072,
}Expand description
The particle type. Can be combined with the | operator.
Variants
b2_waterParticle = 0
Water particle.
b2_zombieParticle = 2
Removed after next simulation step.
b2_wallParticle = 4
Zero velocity.
b2_springParticle = 8
With restitution from stretching.
b2_elasticParticle = 16
With restitution from deformation.
b2_viscousParticle = 32
With viscosity.
b2_powderParticle = 64
Without isotropic pressure.
b2_tensileParticle = 128
With surface tension.
b2_colorMixingParticle = 256
Mix color between contacting particles.
b2_destructionListenerParticle = 512
Call b2DestructionListener on destruction.
b2_barrierParticle = 1_024
Prevents other particles from leaking.
b2_staticPressureParticle = 2_048
Less compressibility.
b2_reactiveParticle = 4_096
Makes pairs or triads with other particles.
b2_repulsiveParticle = 8_192
With high repulsive force.
b2_fixtureContactListenerParticle = 16_384
Call b2ContactListener when this particle is about to interact with a rigid body or stops interacting with a rigid body. This results in an expensive operation compared to using b2_fixtureContactFilterParticle to detect collisions between particles.
b2_particleContactListenerParticle = 32_768
Call b2ContactListener when this particle is about to interact with another particle or stops interacting with another particle. This results in an expensive operation compared to using b2_particleContactFilterParticle to detect collisions between particles.
b2_fixtureContactFilterParticle = 65_536
Call b2ContactFilter when this particle interacts with rigid bodies.
b2_particleContactFilterParticle = 131_072
Call b2ContactFilter when this particle interacts with other particles.