pub struct b2GearJointDef { /* private fields */ }Expand description
Gear joint definition. This definition requires two existing revolute or prismatic joints (any combination will work). @warning bodyB on the input joints must both be dynamic
Implementations