b2Joint

Struct b2Joint 

pub struct b2Joint { /* private fields */ }
The base joint class. Joints are used to constraint two bodies together in various fashions. Some joints also feature limits and motors.

Implementations

Source

impl b2Joint

pub fn GetType(self: &b2Joint) -> b2JointType

Get the type of the concrete joint.

pub fn GetNext(self: Pin<&mut b2Joint>) -> *mut b2Joint

Get the next joint the world joint list.

pub fn GetNext1(self: &b2Joint) -> *const b2Joint

pub fn GetUserData<'a>( self: Pin<&'a mut b2Joint>, ) -> Pin<&'a mut b2JointUserData>

Get the user data pointer.

pub fn IsEnabled(self: &b2Joint) -> bool

Short-cut function to determine if either body is enabled.

pub fn GetAnchorA(self: &b2Joint) -> b2Vec2

Get the anchor point on bodyA in world coordinates.

pub fn GetAnchorB(self: &b2Joint) -> b2Vec2

Get the anchor point on bodyB in world coordinates.

pub fn GetReactionForce(self: &b2Joint, inv_dt: f32) -> b2Vec2

Get the reaction force on bodyB at the joint anchor in Newtons.

pub fn GetReactionTorque(self: &b2Joint, inv_dt: f32) -> f32

Get the reaction torque on bodyB in N*m.

pub fn Dump(self: Pin<&mut b2Joint>)

Dump this joint to the log file.

pub fn ShiftOrigin(self: Pin<&mut b2Joint>, newOrigin: &b2Vec2)

Shift the origin for any points stored in world coordinates.

pub unsafe fn Draw(self: &b2Joint, draw: *mut b2Draw)

Debug draw this joint

Source

impl b2Joint

pub fn GetBodyA(self: Pin<&mut Self>) -> *mut b2Body

Get the first body attached to this joint.

pub fn GetBodyB(self: Pin<&mut Self>) -> *mut b2Body

Get the second body attached to this joint.

pub fn GetCollideConnected(&self) -> bool

Get collide connected. Note: modifying the collide connect flag won’t work correctly because the flag is only checked when fixture AABBs begin to overlap.