pub struct b2PulleyJointDef { /* private fields */ }Expand description
Pulley joint definition. This requires two ground anchors, two dynamic body anchor points, and a pulley ratio.
Implementations
Sourceimpl b2PulleyJointDef
impl b2PulleyJointDef
Sourcepub unsafe fn Initialize(
self: Pin<&mut b2PulleyJointDef>,
bodyA: *mut b2Body,
bodyB: *mut b2Body,
groundAnchorA: &b2Vec2,
groundAnchorB: &b2Vec2,
anchorA: &b2Vec2,
anchorB: &b2Vec2,
ratio: f32,
)
pub unsafe fn Initialize( self: Pin<&mut b2PulleyJointDef>, bodyA: *mut b2Body, bodyB: *mut b2Body, groundAnchorA: &b2Vec2, groundAnchorB: &b2Vec2, anchorA: &b2Vec2, anchorB: &b2Vec2, ratio: f32, )
Initialize the bodies, anchors, lengths, max lengths, and ratio using the world anchors.
pub fn new() -> impl New<Output = Self>