b2RevoluteJointDef

Struct b2RevoluteJointDef 

pub struct b2RevoluteJointDef { /* private fields */ }
Revolute joint definition. This requires defining an anchor point where the bodies are joined. The definition uses local anchor points so that the initial configuration can violate the constraint slightly. You also need to specify the initial relative angle for joint limits. This helps when saving and loading a game. The local anchor points are measured from the body’s origin rather than the center of mass because:

  1. you might not know where the center of mass will be.
  2. if you add/remove shapes from a body and recompute the mass, the joints will be broken.

Implementations

Source

impl b2RevoluteJointDef

pub unsafe fn Initialize( self: Pin<&mut b2RevoluteJointDef>, bodyA: *mut b2Body, bodyB: *mut b2Body, anchor: &b2Vec2, )

Initialize the bodies, anchors, and reference angle using a world anchor point.

pub fn new() -> impl New<Output = Self>