b2WorldManifold

Struct b2WorldManifold 

#[repr(C)]
pub struct b2WorldManifold { pub normal: b2Vec2, pub points: [b2Vec2; 2], pub separations: [f32; 2], }
This is used to compute the current state of a contact manifold.

Fields

normal: b2Vec2

< world vector pointing from A to B

points: [b2Vec2; 2]

< world contact point (point of intersection)

separations: [f32; 2]

< a negative value indicates overlap, in meters

Implementations

Source

impl b2WorldManifold

pub unsafe fn Initialize( self: Pin<&mut b2WorldManifold>, manifold: *const b2Manifold, xfA: &b2Transform, radiusA: f32, xfB: &b2Transform, radiusB: f32, )

Evaluate the manifold with supplied transforms. This assumes modest motion from the original state. This does not change the point count, impulses, etc. The radii must come from the shapes that generated the manifold.

pub fn new() -> impl New<Output = Self>

Synthesized default constructor.