pub struct b2MotorJoint { /* private fields */ }Expand description
A motor joint is used to control the relative motion between two bodies. A typical usage is to control the movement of a dynamic body with respect to the ground.
Implementations
Sourceimpl b2MotorJoint
impl b2MotorJoint
Sourcepub fn SetMaxForce(self: Pin<&mut b2MotorJoint>, force: f32)
pub fn SetMaxForce(self: Pin<&mut b2MotorJoint>, force: f32)
Set the maximum friction force in N.
Sourcepub fn GetMaxForce(self: &b2MotorJoint) -> f32
pub fn GetMaxForce(self: &b2MotorJoint) -> f32
Get the maximum friction force in N.
Sourcepub fn SetMaxTorque(self: Pin<&mut b2MotorJoint>, torque: f32)
pub fn SetMaxTorque(self: Pin<&mut b2MotorJoint>, torque: f32)
Set the maximum friction torque in N*m.
Sourcepub fn GetMaxTorque(self: &b2MotorJoint) -> f32
pub fn GetMaxTorque(self: &b2MotorJoint) -> f32
Get the maximum friction torque in N*m.
pub fn GetAnchorA(self: &b2MotorJoint) -> b2Vec2
pub fn GetAnchorB(self: &b2MotorJoint) -> b2Vec2
pub fn GetReactionForce(self: &b2MotorJoint, inv_dt: f32) -> b2Vec2
pub fn GetReactionTorque(self: &b2MotorJoint, inv_dt: f32) -> f32
Sourcepub fn Dump(self: Pin<&mut b2MotorJoint>)
pub fn Dump(self: Pin<&mut b2MotorJoint>)
Dump to b2Log
Sourceimpl b2MotorJoint
impl b2MotorJoint
Sourcepub fn SetLinearOffset(self: Pin<&mut Self>, linearOffset: &b2Vec2)
pub fn SetLinearOffset(self: Pin<&mut Self>, linearOffset: &b2Vec2)
Set/get the target linear offset, in frame A, in meters.
pub fn GetLinearOffset<'a>(&'a self) -> &'a b2Vec2
Sourcepub fn SetAngularOffset(self: Pin<&mut Self>, angularOffset: f32)
pub fn SetAngularOffset(self: Pin<&mut Self>, angularOffset: f32)
Set/get the target angular offset, in radians.
pub fn GetAngularOffset(&self) -> f32
Sourcepub fn SetCorrectionFactor(self: Pin<&mut Self>, factor: f32)
pub fn SetCorrectionFactor(self: Pin<&mut Self>, factor: f32)
Set the position correction factor in the range [0,1].
Sourcepub fn GetCorrectionFactor(&self) -> f32
pub fn GetCorrectionFactor(&self) -> f32
Get the position correction factor in the range [0,1].